function discs=CModel(x)

global sigma psi chi alpha gamma beta deltak deltad kappak kappad omega 
global phi yBar T gs StatVars IfSave Lens fks fds kdShock zs fws

nCore=numel(Lens);
discs=zeros(nCore*T-12,1);

%            1   2  3  4  5  6  7   8   9 10 11 12 13 14  15     16  17  18  19 20  
%      Core: y  py  k  d  r  w  c  pk  pd
%      Aux                                 h qk qd cy  m  mu
%      Other                                                   invk invd g
%      fks fds      

Loc=1;
var=1;
ys=[0;x(Loc:Loc+Lens(var)-1)];
Loc=Loc+Lens(var);
var=var+1;
pys=[0;x(Loc:Loc+Lens(var)-1)];
Loc=Loc+Lens(var);
var=var+1;
ks=[StatVars(var)*(1+kdShock);x(Loc:Loc+Lens(var)-1);StatVars(var)]; % k is k* in periods 1 and T
Loc=Loc+Lens(var);
var=var+1;
ds=[StatVars(var)*(1+kdShock);x(Loc:Loc+Lens(var)-1);StatVars(var)];
Loc=Loc+Lens(var);
var=var+1;
rs=[0;x(Loc:Loc+Lens(var)-1);0]; %  rs(T) is undefined
Loc=Loc+Lens(var);
var=var+1;
ws=[0;x(Loc:Loc+Lens(var)-1)];
Loc=Loc+Lens(var);
var=var+1;
cs=[0;x(Loc:Loc+Lens(var)-1)];
Loc=Loc+Lens(var);
var=var+1;
pks=[0;x(Loc:Loc+Lens(var)-1)];
Loc=Loc+Lens(var);
var=var+1;
pds=[0;x(Loc:Loc+Lens(var)-1)];

%  Auxiliary variables

hs=zeros(T,1);
qks=zeros(T,1);
qds=zeros(T,1);
cys=zeros(T,1);
ms=zeros(T,1);
mus=zeros(T,1);
invks=zeros(T,1);
invds=zeros(T,1);

for t=2:T
    %  Markup ratio
    mus(t)=zs(t)*(ys(t)/yBar)^(-omega);
    %  Labor input
    hs(t)=alpha*pys(t)*ys(t)/(mus(t)*(1+fws(t))*ws(t));
    %  Tobin's q for capital
    qks(t)=kappak*(ks(t)-ks(t-1))/ks(t-1) +1;
    %  Tobin's q for housing
    qds(t)=kappad*(ds(t)-ds(t-1))/ds(t-1) +1;
    %  Consumption of standard goods
    cys(t)=phi*cs(t)/pys(t);
end
% Discounter
for t=2:T-1
    mucN=cs(t)^(-1/sigma)*(1-chi*(1-1/sigma)*hs(t)^(1+1/psi));
    mucF=cs(t+1)^(-1/sigma)*(1-chi*(1-1/sigma)*hs(t+1)^(1+1/psi));
    ms(t)=beta*mucF/mucN;
end

%  Discrepancies 

iDisc=1;
for t=2:T
    % Production
    discs(iDisc)=ys(t)-hs(t)^alpha*ks(t-1)^(1-alpha);
    iDisc=iDisc+1;
    % Capital and housing 
    discs(iDisc)=ks(t-1)-(1-alpha)*pys(t)*ys(t)/(mus(t)*pks(t));
    iDisc=iDisc+1;
    discs(iDisc)=pds(t)*ds(t-1)-(1-phi)*cs(t);
    iDisc=iDisc+1;
    % Labor supply
    muc=cs(t)^(-1/sigma)*(1-chi*(1-1/sigma)*hs(t)^(1+1/psi));
    muh=(-chi*(1+1/psi)*cs(t)^(1-1/sigma)-gamma)*hs(t)^(1/psi);
    discs(iDisc)=muh+ws(t)*muc;
    iDisc=iDisc+1;
    % Material balance
    invks(t)=ks(t)-(1-deltak)*ks(t-1)+kappak*(ks(t)-ks(t-1))^2/(2*ks(t-1));
    invds(t)=ds(t)-(1-deltad)*ds(t-1)+kappad*(ds(t)-ds(t-1))^2/(2*ds(t-1));
    discs(iDisc)=ys(t)-cys(t)-invks(t)-invds(t)-gs(t);
    iDisc=iDisc+1;
    %  Normalized consumption price
    discs(iDisc)=1-phi^(-phi)*(1-phi)^(-(1-phi))*pys(t)^phi*pds(t)^(1-phi);
    iDisc=iDisc+1;
end

%  Euler 

for t=2:T-1
    discs(iDisc)=(1+rs(t))*ms(t)-1;
    iDisc=iDisc+1;
end

%  Rental prices

for t=3:T
    discs(iDisc)=pks(t)-((1+rs(t-1))*(1+fks(t-1))*qks(t-1)*pys(t-1)-(1-deltak)*qks(t)*pys(t));
    iDisc=iDisc+1;
    discs(iDisc)=pds(t)-((1+rs(t-1))*(1+fds(t-1))*qds(t-1)*pys(t-1)-(1-deltad)*qds(t)*pys(t));
    iDisc=iDisc+1;
end

if IfSave==0
    return
end
%            1   2  3  4  5  6  7   8   9 10 11 12 13 14  15     16  17  18  19 20  
%      Core: y  py  k  d  r  w  c  pk  pd
%      Aux                                 h qk qd cy  m  mu
%      Other                                                   invk invd g   fks fds      

AllVars=[ys,pys,ks,ds,rs,ws,cs,pks,pds,hs,qks,qds,cys,ms,mus,invks,invds,gs,fks,fds,zs,fws];
save CModel AllVars
